@@ -1,8 +1,8 @@
-#!/usr/bin/env python3.9
+#!/usr/bin/env python3.10
 # coding:utf-8
 # Copyright (C) 2022-2025 All rights reserved.
 # FILENAME:    ~~/src/aesir/__init__.py
-# VERSION:     0.5.0
+# VERSION:     0.5.3
 # CREATED:     2023-12-01 05:31
 # AUTHOR:      Sitt Guruvanich <aekasitt.g+github@siamintech.co.th>
 # DESCRIPTION: https://www.w3docs.com/snippets/python/what-is-init-py-for.html
@@ -13,6 +13,14 @@
 ### Local modules ###
 from aesir.commands import build, clean, deploy, invoice, mine, nodekeys, ping_pong, pull
 
-__all__ = ("build", "clean", "deploy", "invoice", "mine", "nodekeys", "ping_pong", "pull")
-
-__version__ = "0.5.0"
+__all__: tuple[str, ...] = (
+  "build",
+  "clean",
+  "deploy",
+  "invoice",
+  "mine",
+  "nodekeys",
+  "ping_pong",
+  "pull",
+)
+__version__: str = "0.5.3"
