@@ -1,8 +1,8 @@
-#!/usr/bin/env python3.9
+#!/usr/bin/env python3.10
 # coding:utf-8
 # Copyright (C) 2022-2025 All rights reserved.
 # FILENAME:    ~~/src/aesir/commands/__init__.py
-# VERSION:     0.5.0
+# VERSION:     0.5.3
 # CREATED:     2023-12-01 05:31
 # AUTHOR:      Sitt Guruvanich <aekasitt.g+github@siamintech.co.th>
 # DESCRIPTION: https://www.w3docs.com/snippets/python/what-is-init-py-for.html
@@ -20,4 +20,13 @@ from aesir.commands.nodekeys import nodekeys
 from aesir.commands.ping_pong import ping_pong
 from aesir.commands.pull import pull
 
-__all__ = ("build", "clean", "deploy", "invoice", "mine", "nodekeys", "ping_pong", "pull")
+__all__: tuple[str, ...] = (
+  "build",
+  "clean",
+  "deploy",
+  "invoice",
+  "mine",
+  "nodekeys",
+  "ping_pong",
+  "pull",
+)
