@@ -1,8 +1,8 @@
-#!/usr/bin/env python3.9
+#!/usr/bin/env python3.10
 # coding:utf-8
 # Copyright (C) 2022-2025 All rights reserved.
 # FILENAME:    ~~/src/aesir/types/__init__.py
-# VERSION:     0.5.0
+# VERSION:     0.5.3
 # CREATED:     2023-12-01 05:31
 # AUTHOR:      Sitt Guruvanich <aekasitt.g+github@siamintech.co.th>
 # DESCRIPTION: https://www.w3docs.com/snippets/python/what-is-init-py-for.html
@@ -13,34 +13,39 @@
 ### Local modules ###
 from aesir.types.blockchain_info import BlockchainInfo
 from aesir.types.build import Build, BuildEnum
+from aesir.types.chunk import Chunk, ErrorDetail
 from aesir.types.cluster_enum import ClusterEnum
-from aesir.types.connection import Connection
-from aesir.types.image import ImageAlias, ImageEnum
+from aesir.types.features import Features
+from aesir.types.image import Image
+from aesir.types.jsonrpc import JsonrpcError, JsonrpcResponse
 from aesir.types.lnd_info import LNDInfo
 from aesir.types.lnd_invoice import LNDInvoice
 from aesir.types.mempool_info import MempoolInfo
 from aesir.types.mutex_option import MutexOption
 from aesir.types.new_address import NewAddress
 from aesir.types.open_channel import OpenChannel
-from aesir.types.peripheral_enum import PeripheralEnum
+from aesir.types.ord_status import OrdStatus
 from aesir.types.service import Service, ServiceName
 
 
-__all__ = (
+__all__: tuple[str, ...] = (
   "BlockchainInfo",
   "Build",
   "BuildEnum",
+  "Chunk",
   "ClusterEnum",
-  "Connection",
-  "ImageAlias",
-  "ImageEnum",
+  "ErrorDetail",
+  "Features",
+  "Image",
+  "JsonrpcError",
+  "JsonrpcResponse",
   "LNDInfo",
   "LNDInvoice",
   "MempoolInfo",
   "MutexOption",
   "NewAddress",
   "OpenChannel",
-  "PeripheralEnum",
+  "OrdStatus",
   "Service",
   "ServiceName",
 )
