@@ -1,8 +1,8 @@
-#!/usr/bin/env python3.9
+#!/usr/bin/env python3.10
 # coding:utf-8
 # Copyright (C) 2022-2025 All rights reserved.
 # FILENAME:    ~~/src/aesir/types/blockchain_info.py
-# VERSION:     0.5.0
+# VERSION:     0.5.3
 # CREATED:     2023-12-01 05:31
 # AUTHOR:      Sitt Guruvanich <aekasitt.g+github@siamintech.co.th>
 # DESCRIPTION:
@@ -15,10 +15,10 @@ from pydantic import BaseModel, StrictInt, StrictStr
 
 
 class BlockchainInfo(BaseModel):
-  blocks: StrictInt
-  chain: StrictStr
-  size_on_disk: StrictInt
-  time: StrictInt
+  blocks: StrictInt = 0
+  chain: StrictStr = ""
+  size_on_disk: StrictInt = 0
+  time: StrictInt = 0
 
 
-__all__ = ("BlockchainInfo",)
+__all__: tuple[str, ...] = ("BlockchainInfo",)
