@@ -1,8 +1,8 @@
-#!/usr/bin/env python3.9
+#!/usr/bin/env python3.10
 # coding:utf-8
 # Copyright (C) 2022-2025 All rights reserved.
 # FILENAME:    ~~/src/aesir/types/cluster_enum.py
-# VERSION:     0.5.0
+# VERSION:     0.5.3
 # CREATED:     2023-12-01 05:31
 # AUTHOR:      Sitt Guruvanich <aekasitt.g+github@siamintech.co.th>
 # DESCRIPTION:
@@ -15,4 +15,4 @@ from typing import Literal
 
 ClusterEnum = Literal["cat", "duo", "ohm", "uno"]
 
-__all__ = ("ClusterEnum",)
+__all__: tuple[str, ...] = ("ClusterEnum",)
