@@ -1,8 +1,8 @@
-#!/usr/bin/env python3.9
+#!/usr/bin/env python3.10
 # coding:utf-8
 # Copyright (C) 2022-2025 All rights reserved.
 # FILENAME:    ~~/src/aesir/types/image.py
-# VERSION:     0.5.0
+# VERSION:     0.5.3
 # CREATED:     2023-12-01 05:31
 # AUTHOR:      Sitt Guruvanich <aekasitt.g+github@siamintech.co.th>
 # DESCRIPTION:
@@ -13,9 +13,9 @@
 ### Standard packages ###
 from typing import Literal
 
-ImageAlias = Literal[
-  "bitcoind", "bitcoind-cat", "cashu-mint", "lnd", "lnd-krub", "ord-server", "postgres", "redis"
-]
-ImageEnum = Literal["optional", "required"]
+### Local modules ###
+from aesir.types.build import BuildEnum
 
-__all__ = ("ImageAlias", "ImageEnum")
+Image = BuildEnum | Literal["postgres:latest", "redis:latest"]
+
+__all__: tuple[str, ...] = ("Image",)
