@@ -1,8 +1,8 @@
-#!/usr/bin/env python3.9
+#!/usr/bin/env python3.10
 # coding:utf-8
 # Copyright (C) 2022-2025 All rights reserved.
 # FILENAME:    ~~/src/aesir/types/lnd_invoice.py
-# VERSION:     0.5.0
+# VERSION:     0.5.3
 # CREATED:     2024-11-15 00:56
 # AUTHOR:      Sitt Guruvanich <aekasitt.g+github@siamintech.co.th>
 # DESCRIPTION:
@@ -21,4 +21,4 @@ class LNDInvoice(BaseModel):
   payment_request: StrictStr
 
 
-__all__ = ("LNDInvoice",)
+__all__: tuple[str, ...] = ("LNDInvoice",)
