@@ -1,8 +1,8 @@
-#!/usr/bin/env python3.9
+#!/usr/bin/env python3.10
 # coding:utf-8
 # Copyright (C) 2022-2025 All rights reserved.
 # FILENAME:    ~~/src/aesir/types/open_channel.py
-# VERSION:     0.5.0
+# VERSION:     0.5.3
 # CREATED:     2023-12-02 20:50
 # AUTHOR:      Sitt Guruvanich <aekasitt.g+github@siamintech.co.th>
 # DESCRIPTION:
@@ -18,4 +18,4 @@ class OpenChannel(BaseModel):
   funding_txid: StrictStr
 
 
-__all__ = ("OpenChannel",)
+__all__: tuple[str, ...] = ("OpenChannel",)
