@@ -1,8 +1,8 @@
-#!/usr/bin/env python3.9
+#!/usr/bin/env python3.10
 # coding:utf-8
 # Copyright (C) 2022-2025 All rights reserved.
 # FILENAME:    ~~/src/aesir/types/service.py
-# VERSION:     0.5.0
+# VERSION:     0.5.3
 # CREATED:     2023-12-01 05:31
 # AUTHOR:      Sitt Guruvanich <aekasitt.g+github@siamintech.co.th>
 # DESCRIPTION:
@@ -11,28 +11,27 @@
 # *************************************************************
 
 ### Standard packages ###
-from typing import List, Literal
+from typing import Literal, Mapping
 
 ### Third-party packages ###
 from pydantic import BaseModel, StrictStr
 
 ### Local modules ###
-from aesir.types.image import ImageAlias
+from aesir.types.image import Image
 
 
 class Service(BaseModel):
-  alias: ImageAlias
-  command: List[StrictStr] = []
-  env_vars: List[StrictStr] = []
-  ports: List[StrictStr]
+  command: Mapping[int, StrictStr] = {}
+  env_vars: list[StrictStr] = []
+  image: Image
+  ports: list[StrictStr]
 
 
 ServiceName = Literal[
   "aesir-bitcoind",
-  "aesir-bitcoind-cat",
   "aesir-cashu-mint",
+  "aesir-electrs",
   "aesir-lnd",
-  "aesir-lnd-krub",
   "aesir-ord-server",
   "aesir-ping",
   "aesir-pong",
@@ -40,4 +39,4 @@ ServiceName = Literal[
   "aesir-redis",
 ]
 
-__all__ = ("Service", "ServiceName")
+__all__: tuple[str, ...] = ("Service", "ServiceName")
