@@ -1,8 +1,8 @@
-#!/usr/bin/env python3.9
+#!/usr/bin/env python3.10
 # coding:utf-8
 # Copyright (C) 2022-2025 All rights reserved.
 # FILENAME:    ~~/src/aesir/views/__init__.py
-# VERSION:     0.5.0
+# VERSION:     0.5.3
 # CREATED:     2024-06-25 19:43
 # AUTHOR:      Sitt Guruvanich <aekasitt.g+github@siamintech.co.th>
 # DESCRIPTION: https://www.w3docs.com/snippets/python/what-is-init-py-for.html
@@ -14,4 +14,4 @@
 from aesir.views.bifrost import Bifrost
 from aesir.views.yggdrasil import Yggdrasil
 
-__all__ = ("Bifrost", "Yggdrasil")
+__all__: tuple[str, ...] = ("Bifrost", "Yggdrasil")
